@@ -132,9 +132,10 @@ class GitDiffReporter(BaseDiffReporter):
 
                     # Remove any lines from the dict that have been deleted
                     # Include any lines that have been added
-                    result_dict[src_path] = \
-                            [line for line in result_dict.get(src_path, [])
-                             if not line in deleted_lines] + added_lines
+                    result_dict[src_path] = [
+                        line for line in result_dict.get(src_path, [])
+                        if not line in deleted_lines
+                    ] + added_lines
 
             # Eliminate repeats and order line numbers
             for (src_path, lines) in result_dict.items():
@@ -147,7 +148,7 @@ class GitDiffReporter(BaseDiffReporter):
         return self._diff_dict
 
     # Regular expressions used to parse the diff output
-    SRC_FILE_RE = re.compile(r'^diff --git a/.* b/([^ \n]*)')
+    SRC_FILE_RE = re.compile(r'^diff --git "?a/.*"? "?b/([^ \n"]*)"?')
     MERGE_CONFLICT_RE = re.compile(r'^diff --cc ([^ \n]*)')
     HUNK_LINE_RE = re.compile(r'\+([0-9]*)')
 
@@ -340,7 +341,7 @@ class GitDiffReporter(BaseDiffReporter):
         The format of the hunk line is:
 
             @@ -k,l +n,m @@ TEXT
-        
+
         where `k,l` represent the start line and length before the changes
         and `n,m` represent the start line and length after the changes.
 
